# get connection and exist engine test
--echo for master_1
--connection master_1
--echo for child2
if ($USE_CHILD_GROUP2)
{
  --echo child2_1
  --echo child2_2
  --echo child2_3
}
--echo for child3
if ($USE_CHILD_GROUP3)
{
  --echo child3_1
  --connection child3_1
  --source ../include/ha_deinit_child3_1.inc
  --echo child3_2
  --connection child3_2
  --source ../include/ha_deinit_child3_2.inc
  --echo child3_3
  --connection child3_3
  --source ../include/ha_deinit_child3_3.inc
}
