SET SESSION query_response_time_exec_time_debug=100000;

SET GLOBAL QUERY_RESPONSE_TIME_STATS=0;
EVAL SET GLOBAL QUERY_RESPONSE_TIME_RANGE_BASE=$base;
SET GLOBAL query_response_time_flush=1;
SET GLOBAL QUERY_RESPONSE_TIME_STATS=1;

CALL test_f(310000);
CALL test_f(320000);
CALL test_f(330000);
CALL test_f(340000);
CALL test_f(350000);
CALL test_f(360000);
CALL test_f(370000);
CALL test_f(380000);
CALL test_f(390000);
CALL test_f(400000);
CALL test_f(1100000);
CALL test_f(1200000);
CALL test_f(1300000);
CALL test_f(1500000);
CALL test_f(1400000);
CALL test_f(500000);
CALL test_f(2100000);
CALL test_f(2300000);
CALL test_f(2500000);
CALL test_f(3100000);
CALL test_f(4100000);
CALL test_f(5100000);

SET GLOBAL QUERY_RESPONSE_TIME_STATS=0;

SHOW GLOBAL VARIABLES where Variable_name like 'QUERY_RESPONSE_TIME_RANGE_BASE';
SELECT * FROM INFORMATION_SCHEMA.QUERY_RESPONSE_TIME;

SET SESSION query_response_time_exec_time_debug=default;
