##############################################################################
#
#  List the test cases that are to be disabled temporarily.
#
#  Separate the test case name and the comment with ':'.
#
#    <testcasename> : BUG#<xxxx> <date disabled> <disabler> <comment>
#
#  Do not use any TAB characters for whitespace.
#
##############################################################################
sizing_off: not updated for 10.0 yet
sizing_med: not updated for 10.0 yet
sizing_low: not updated for 10.0 yet
sizing_high: not updated for 10.0 yet
sizing_growth: not updated for 10.0 yet
sizing_default: not updated for 10.0 yet

binlog_edge_mix: needs slave_relay_log_info
binlog_edge_row: needs slave_relay_log_info
binlog_edge_stmt: needs slave_relay_log_info
binlog_ok_mix: needs slave_relay_log_info
binlog_ok_row: needs slave_relay_log_info
binlog_ok_stmt: needs slave_relay_log_info

server_init : Nirbhay TODO: Fix the test
show_sanity:
threads_mysql_freebsd:

transaction_gtid: needs to be updated for MariaDB gtids

ddl_replication_connection_status: todo
dml_replication_connection_status: todo

dml_replication_group_member_stats: todo?
ddl_replication_group_member_stats: todo?
ddl_replication_group_members: todo?
dml_replication_group_members: todo?
replication_group_members: todo?
replication_group_member_stats: todo?
rpl_group_member_stats: todo?
rpl_group_members: todo?

ddl_session_variables: todo
ddl_global_variables: todo
ddl_variables_by_thread: todo
dml_global_variables: todo
dml_session_variables: todo
dml_variables_by_thread: todo
variables_by_thread: todo
show_coverage: todo
show_misc: todo
show_plugin: todo

status_reprepare:why P_S filters out Com_* variables?

processlist: todo
processlist_acl: todo
processlist_port: todo
processlist_no_pfs: todo
ddl_processlist: todo
dml_processlist: todo
processlist_57: todo
processlist_anonymous: todo
processlist_reg_user: todo
